@@ -100,13 +100,18 @@ lapply(
         as.data.frame.simstatespace(ssm, eta = FALSE)
         as.data.frame.simstatespace(ssm, eta = TRUE, long = FALSE)
         as.data.frame.simstatespace(ssm, eta = FALSE, long = FALSE)
+        as.data.frame.simstatespace(ssm, burnin = 5, reset_time = TRUE)
+        as.data.frame.simstatespace(ssm, burnin = 5, reset_time = FALSE)
         as.matrix.simstatespace(ssm, eta = TRUE)
         as.matrix.simstatespace(ssm, eta = FALSE)
         as.matrix.simstatespace(ssm, eta = TRUE, long = FALSE)
         as.matrix.simstatespace(ssm, eta = FALSE, long = FALSE)
+        as.matrix.simstatespace(ssm, burnin = 5, reset_time = TRUE)
+        as.matrix.simstatespace(ssm, burnin = 5, reset_time = FALSE)
         print.simstatespace(ssm)
-        plot.simstatespace(ssm, id = 1:3, time = (0:4) * 0.10)
+        plot.simstatespace(ssm, id = 1:3, time = 0:4)
         plot.simstatespace(ssm, eta = TRUE)
+        plot.simstatespace(ssm, burnin = 5, reset_time = FALSE)
 
         # Type 1
         ssm <- SimSSMLinSDEIVary(
@@ -130,13 +135,18 @@ lapply(
         as.data.frame.simstatespace(ssm, eta = FALSE)
         as.data.frame.simstatespace(ssm, eta = TRUE, long = FALSE)
         as.data.frame.simstatespace(ssm, eta = FALSE, long = FALSE)
+        as.data.frame.simstatespace(ssm, burnin = 5, reset_time = TRUE)
+        as.data.frame.simstatespace(ssm, burnin = 5, reset_time = FALSE)
         as.matrix.simstatespace(ssm, eta = TRUE)
         as.matrix.simstatespace(ssm, eta = FALSE)
         as.matrix.simstatespace(ssm, eta = TRUE, long = FALSE)
         as.matrix.simstatespace(ssm, eta = FALSE, long = FALSE)
+        as.matrix.simstatespace(ssm, burnin = 5, reset_time = TRUE)
+        as.matrix.simstatespace(ssm, burnin = 5, reset_time = FALSE)
         print.simstatespace(ssm)
-        plot.simstatespace(ssm, id = 1:3, time = (0:4) * 0.10)
+        plot.simstatespace(ssm, id = 1:3, time = 0:4)
         plot.simstatespace(ssm, eta = TRUE)
+        plot.simstatespace(ssm, burnin = 5, reset_time = FALSE)
 
         # Type 2
         ssm <- SimSSMLinSDEIVary(
@@ -161,13 +171,18 @@ lapply(
         as.data.frame.simstatespace(ssm, eta = FALSE)
         as.data.frame.simstatespace(ssm, eta = TRUE, long = FALSE)
         as.data.frame.simstatespace(ssm, eta = FALSE, long = FALSE)
+        as.data.frame.simstatespace(ssm, burnin = 5, reset_time = TRUE)
+        as.data.frame.simstatespace(ssm, burnin = 5, reset_time = FALSE)
         as.matrix.simstatespace(ssm, eta = TRUE)
         as.matrix.simstatespace(ssm, eta = FALSE)
         as.matrix.simstatespace(ssm, eta = TRUE, long = FALSE)
         as.matrix.simstatespace(ssm, eta = FALSE, long = FALSE)
+        as.matrix.simstatespace(ssm, burnin = 5, reset_time = TRUE)
+        as.matrix.simstatespace(ssm, burnin = 5, reset_time = FALSE)
         print.simstatespace(ssm)
-        plot.simstatespace(ssm, id = 1:3, time = (0:4) * 0.10)
+        plot.simstatespace(ssm, id = 1:3, time = 0:4)
         plot.simstatespace(ssm, eta = TRUE)
+        plot.simstatespace(ssm, burnin = 5, reset_time = FALSE)
 
         # sigma_l zero --------------------------------------------
         sigma_l <- list(
@@ -231,6 +246,13 @@ lapply(
           kappa = kappa
         )
 
+        testthat::expect_error(
+          as.matrix.simstatespace(ssm, burnin = time),
+          regexp = paste0(
+            "`burnin` should not be greater than the measurement occasions.\n"
+          )
+        )
+
         testthat::expect_true(
           TRUE
         )
